pub enum MotionFrameDemand {
Idle,
NeedsFrame(MotionFrameReason),
}Expand description
Renderer-neutral frame demand returned by motion controllers.
Variants
Idle
No more animation frames are required.
NeedsFrame(MotionFrameReason)
At least one track is active and the adapter should request another frame for the reason.
Implementations
Sourceimpl MotionFrameDemand
impl MotionFrameDemand
Sourcepub const fn needs_frame(self) -> bool
pub const fn needs_frame(self) -> bool
Returns whether another frame should be requested by the adapter.
Sourcepub const fn reason(self) -> Option<MotionFrameReason>
pub const fn reason(self) -> Option<MotionFrameReason>
Returns the reason another frame is needed.
Sourcepub const fn combine(self, other: Self) -> Self
pub const fn combine(self, other: Self) -> Self
Combines two frame demands into one adapter-owned frame request.
Sourcepub fn combine_all(demands: impl IntoIterator<Item = Self>) -> Self
pub fn combine_all(demands: impl IntoIterator<Item = Self>) -> Self
Combines many frame demands into one adapter-owned frame request.