pub struct MotionProjection { /* private fields */ }Expand description
Projection from previous geometry to final target geometry.
Implementations
Sourceimpl MotionProjection
impl MotionProjection
Sourcepub const fn between(source: MotionRect, target: MotionRect) -> Self
pub const fn between(source: MotionRect, target: MotionRect) -> Self
Creates a projection between a source rect and final target rect.
Sourcepub const fn source(self) -> MotionRect
pub const fn source(self) -> MotionRect
Returns the source rect.
Sourcepub const fn target(self) -> MotionRect
pub const fn target(self) -> MotionRect
Returns the final target rect.
Sourcepub fn visual_bounds(self, progress: f32) -> MotionRect
pub fn visual_bounds(self, progress: f32) -> MotionRect
Returns the sampled visual bounds after applying projection movement to final-size content.
Sourcepub fn visual_bounds_with_preference(
self,
progress: f32,
preference: MotionPreference,
) -> MotionRect
pub fn visual_bounds_with_preference( self, progress: f32, preference: MotionPreference, ) -> MotionRect
Returns the sampled visual bounds while honoring reduced-motion final-state semantics.