MotionProjectionClip

Struct MotionProjectionClip 

pub struct MotionProjectionClip { /* private fields */ }
Sampled clip for rendering final-size content through a moving or revealing viewport.

Implementations

Source

impl MotionProjectionClip

pub fn new( content_bounds: MotionRect, visible_bounds: MotionRect, occlusion_bounds: MotionRect, progress: f32, ) -> Self

Creates a sampled clip from explicit final-content, visible, and occlusion bounds.

pub fn from_projection(projection: MotionProjection, progress: f32) -> Self

Creates a projection clip from previous geometry to final semantic geometry.

pub fn from_projection_with_preference( projection: MotionProjection, progress: f32, preference: MotionPreference, ) -> Self

Creates a projection clip while honoring reduced-motion final-state semantics.

pub fn reveal( content_bounds: MotionRect, edge: MotionEdge, progress: f32, ) -> Self

Creates a reveal clip inside final content bounds from the chosen edge.

pub const fn content_bounds(self) -> MotionRect

Returns the final-size content bounds.

pub const fn visible_bounds(self) -> MotionRect

Returns the sampled visible viewport bounds.

pub const fn occlusion_bounds(self) -> MotionRect

Returns the occlusion bounds that cover the snapped final scene underneath.

pub const fn progress(self) -> f32

Returns clamped clip progress.