pub enum MotionRunState {
Immediate,
Active,
Completed,
Cancelled,
}Expand description
Runtime state for sampled motion.
Variants
Immediate
The motion spec completed immediately.
Active
The motion run is still active.
Completed
The motion run reached its final state.
Cancelled
The motion run was cancelled before reaching its final state.
Implementations
Sourceimpl MotionRunState
impl MotionRunState
Sourcepub const fn is_active(self) -> bool
pub const fn is_active(self) -> bool
Returns whether callers should continue requesting animation frames.
Sourcepub const fn is_terminal(self) -> bool
pub const fn is_terminal(self) -> bool
Returns whether the timeline no longer needs animation frames.
Sourcepub const fn reached_final_state(self) -> bool
pub const fn reached_final_state(self) -> bool
Returns whether the semantic final state has been reached.