pub fn lerp_rect(from: MotionRect, to: MotionRect, progress: f32) -> MotionRectExpand description
Samples a rect between two rects at unit progress.
pub fn lerp_rect(from: MotionRect, to: MotionRect, progress: f32) -> MotionRectSamples a rect between two rects at unit progress.