pub fn motion_source_rect(
edge: MotionEdge,
final_bounds: MotionRect,
container: MotionRect,
) -> MotionRectExpand description
Returns bounds for the rect just outside the container on the chosen edge.
pub fn motion_source_rect(
edge: MotionEdge,
final_bounds: MotionRect,
container: MotionRect,
) -> MotionRectReturns bounds for the rect just outside the container on the chosen edge.