MotionSequenceStep

Struct MotionSequenceStep 

pub struct MotionSequenceStep<K> { /* private fields */ }
One keyed sequence step.

Implementations

Source

impl<K> MotionSequenceStep<K>

pub fn new(key: K, model: MotionModel, start_at: Duration) -> Self

Creates a sequence step at an absolute sequence elapsed time.

pub const fn key(&self) -> &K

Returns the stable step key.

pub const fn model(&self) -> MotionModel

Returns the step motion model.

pub const fn start_at(&self) -> Duration

Returns the absolute sequence time at which this step starts.

pub const fn duration_hint(&self) -> Duration

Returns the duration hint used for timeline composition.

pub fn end_hint(&self) -> Duration

Returns the hinted end time for this step.

Source

impl<K: Clone> MotionSequenceStep<K>

pub fn sample_at(&self, elapsed: Duration) -> MotionSequenceStepSample<K>

Samples this step at sequence elapsed time.