MotionPreset

Enum MotionPreset 

pub enum MotionPreset {
    Immediate,
    Timeline(MotionSpec),
    Spring(MotionSpringSpec),
    CommittedLayout(MotionPreference),
    Continuity(MotionPreference),
    Affordance(MotionPreference),
}
Explicit preset that resolves to a concrete motion model.

Variants



Immediate

Immediate completion.



Timeline(MotionSpec)

Duration/easing timeline motion.



Spring(MotionSpringSpec)

Explicit spring motion.



CommittedLayout(MotionPreference)

Default committed layout spring.



Continuity(MotionPreference)

Default continuity spring.



Affordance(MotionPreference)

Default affordance spring.

Implementations

Source

impl MotionPreset

pub const fn immediate() -> Self

Creates an immediate preset.

pub const fn timeline(spec: MotionSpec) -> Self

Creates an explicit timeline preset.

pub const fn spring(spec: MotionSpringSpec) -> Self

Creates an explicit spring preset.

pub const fn committed_layout(preference: MotionPreference) -> Self

Creates the default committed layout preset.

pub const fn continuity(preference: MotionPreference) -> Self

Creates the default continuity preset.

pub const fn affordance(preference: MotionPreference) -> Self

Creates the default affordance preset.

pub fn resolve_model(self) -> MotionModel

Resolves this preset to the concrete motion model that should execute.