pub struct MotionClockSample { /* private fields */ }Expand description
Adapter clock sample mapped into deterministic controller elapsed time.
Implementations
Sourceimpl MotionClockSample
impl MotionClockSample
Sourcepub fn from_elapsed(
previous_elapsed: Duration,
requested_elapsed: Duration,
) -> Self
pub fn from_elapsed( previous_elapsed: Duration, requested_elapsed: Duration, ) -> Self
Creates a clock sample from previous and requested elapsed times.
Non-monotonic elapsed time is clamped to the previous elapsed time. This keeps controller sampling deterministic and avoids negative deltas for adapters whose frame clock moves backwards or is restored from stale state.
Sourcepub fn from_instant(started_at: Instant, now: Instant) -> Self
pub fn from_instant(started_at: Instant, now: Instant) -> Self
Creates a clock sample from a start instant and current adapter instant.
Sourcepub fn from_instants(
started_at: Instant,
previous_now: Instant,
now: Instant,
) -> Self
pub fn from_instants( started_at: Instant, previous_now: Instant, now: Instant, ) -> Self
Creates a clock sample from adapter instants and clamps non-monotonic elapsed time.